import * as _zag_js_anatomy from '@zag-js/anatomy';
import { RequiredBy, PropTypes, DirectionProperty, CommonProperties, NormalizeProps } from '@zag-js/types';
import * as _zag_js_core from '@zag-js/core';
import { StateMachine } from '@zag-js/core';

declare const anatomy: _zag_js_anatomy.AnatomyInstance<"root" | "item" | "itemTrigger" | "itemContent" | "itemIndicator">;

interface ValueChangeDetails {
    value: string[];
}
interface FocusChangeDetails {
    value: string | null;
}
type ElementIds = Partial<{
    root: string;
    item(value: string): string;
    content(value: string): string;
    trigger(value: string): string;
}>;
interface PublicContext extends DirectionProperty, CommonProperties {
    /**
     * The ids of the elements in the accordion. Useful for composition.
     */
    ids?: ElementIds;
    /**
     * Whether multple accordion items can be open at the same time.
     * @default false
     */
    multiple?: boolean;
    /**
     * Whether an accordion item can be collapsed after it has been opened.
     * @default false
     */
    collapsible?: boolean;
    /**
     * The `id` of the accordion item that is currently being opened.
     */
    value: string[];
    /**
     * Whether the accordion items are disabled
     */
    disabled?: boolean;
    /**
     * The callback fired when the state of opened/closed accordion items changes.
     */
    onValueChange?: (details: ValueChangeDetails) => void;
    /**
     * The callback fired when the focused accordion item changes.
     */
    onFocusChange?: (details: FocusChangeDetails) => void;
    /**
     *  The orientation of the accordion items.
     */
    orientation?: "horizontal" | "vertical";
}
type UserDefinedContext = RequiredBy<PublicContext, "id">;
type ComputedContext = Readonly<{
    /**
     * @computed
     * Whether the accordion items are horizontal.
     */
    isHorizontal: boolean;
}>;
interface PrivateContext {
}
interface MachineContext extends PublicContext, PrivateContext, ComputedContext {
}
interface MachineState {
    value: "idle" | "focused";
}
type State = StateMachine.State<MachineContext, MachineState>;
type Send = StateMachine.Send<StateMachine.AnyEventObject>;
interface ItemProps {
    value: string;
    disabled?: boolean;
}
interface ItemState {
    isOpen: boolean;
    isFocused: boolean;
    isDisabled: boolean;
}
interface MachineApi<T extends PropTypes = PropTypes> {
    /**
     * The value of the focused accordion item.
     */
    focusedValue: string | null;
    /**
     * The value of the accordion
     */
    value: string[];
    /**
     * Sets the value of the accordion.
     */
    setValue: (value: string[]) => void;
    /**
     * Gets the state of an accordion item.
     */
    getItemState: (props: ItemProps) => ItemState;
    rootProps: T["element"];
    getItemProps(props: ItemProps): T["element"];
    getItemContentProps(props: ItemProps): T["element"];
    getItemTriggerProps(props: ItemProps): T["button"];
    getItemIndicatorProps(props: ItemProps): T["element"];
}

declare function connect<T extends PropTypes>(state: State, send: Send, normalize: NormalizeProps<T>): MachineApi<T>;

declare function machine(userContext: UserDefinedContext): _zag_js_core.Machine<MachineContext, MachineState, _zag_js_core.StateMachine.AnyEventObject>;

declare const props: ("multiple" | "disabled" | "dir" | "id" | "value" | "orientation" | "ids" | "collapsible" | "onValueChange" | "onFocusChange" | "getRootNode")[];
declare const splitProps: <Props extends Partial<UserDefinedContext>>(props: Props) => [Partial<UserDefinedContext>, Omit<Props, "multiple" | "disabled" | "dir" | "id" | "value" | "orientation" | "ids" | "collapsible" | "onValueChange" | "onFocusChange" | "getRootNode">];
declare const itemProps: (keyof ItemProps)[];
declare const splitItemProps: <Props extends ItemProps>(props: Props) => [ItemProps, Omit<Props, keyof ItemProps>];

export { type MachineApi as Api, type UserDefinedContext as Context, type ElementIds, type FocusChangeDetails, type ItemProps, type ItemState, type ValueChangeDetails, anatomy, connect, itemProps, machine, props, splitItemProps, splitProps };
